require 'json'
require 'uri'
require 'net/http'
require 'csv'
require 'openssl'
require "libriciel/version"

module Libriciel

    # Class ApiXivo to use Xivo Api
    class ApiXivo

      def self.token_validation(token)
        url = URI("https://xivo.libriciel.fr:9497/0.1/token/#{token}")

        http = Net::HTTP.new(url.host, url.port)
        http.use_ssl = true
        http.verify_mode = OpenSSL::SSL::VERIFY_NONE

        request = Net::HTTP::Head.new(url)
        request["content-type"] = 'application/json'
        request["cache-control"] = 'no-cache'

        response = http.request(request)

        if response.message == "NO CONTENT"
          return true

        else
          return false

        end
      end

      # Génération du token permettant l'authent ADMIN (ATTENTION) pour l'api Xivo
      def self.token_generate(base64_enc)
        url = URI("https://xivo.libriciel.fr:9497/0.1/token")

        http = Net::HTTP.new(url.host, url.port)
        http.use_ssl = true
        http.verify_mode = OpenSSL::SSL::VERIFY_NONE

        request = Net::HTTP::Post.new(url)
        request["content-type"] = 'application/json'
        request["authorization"] = "Basic #{base64_enc}"
        request["cache-control"] = 'no-cache'

        request.body = "{\n  \"backend\": \"xivo_admin\",\n  \"expiration\": 100\n}"

        response = http.request(request)
        reponse_parsing = JSON.parse(response.read_body)

        if !reponse_parsing.include?("data")
          puts reponse_parsing["reason"]
          exit 223
        else
          token = reponse_parsing['data']['token']
        end

        return token
      end

      # Liste de tous les devices qui sont soit en autoprov (avec leur mac)
      # soit en not_configured
      def self.get_free_devices(token)
        url = URI("https://xivo.libriciel.fr:9486/1.1/devices")

        http = Net::HTTP.new(url.host, url.port)
        http.use_ssl = true
        http.verify_mode = OpenSSL::SSL::VERIFY_NONE

        request = Net::HTTP::Get.new(url)
        request["x-auth-token"] = "#{token}"
        request["cache-control"] = 'no-cache'

        response = http.request(request)

        json = JSON.parse(response.read_body)
        json["items"].each do |devices|
          if devices["status"] == "autoprov"
            puts "\nThe Device #{devices["id"]} is #{devices["status"]}"
            puts "The Devices #{devices["id"]} mac is #{devices["mac"]}\n"
          elsif devices["status"] == "not_configured"
            puts "\nThe Device #{devices["id"]} is #{devices["status"]}"
            puts "The Devices #{devices["id"]} mac is #{devices["mac"]}\n"
          end
        end

      end

      # Fonction qui donne un numéro SIP disponible pour un nouveau user
      def self.get_free_sip(min_sip, max_sip, token)
        sip_number = min_sip
        array_numbers = []
        url = URI("https://xivo.libriciel.fr:9486/1.1/lines")

        http = Net::HTTP.new(url.host, url.port)
        http.use_ssl = true
        http.verify_mode = OpenSSL::SSL::VERIFY_NONE

        request = Net::HTTP::Get.new(url)
        request["x-auth-token"] = "#{token}"
        request["cache-control"] = 'no-cache'

        response = http.request(request)
        json = JSON.parse(response.read_body)
        json2 = json["items"].to_a
        json2.each do |number_check|
          array_numbers << number_check["caller_id_num"]
        end

        while sip_number < max_sip
          if array_numbers.include?(sip_number.to_s)
            sip_number += 1
          else
            return sip_number

          end
        end
      end

      # Liste complète detous les devices avec leurs infos (format ouput: json)
      def self.get_devices(token)
        url = URI("https://xivo.libriciel.fr:9486/1.1/devices")

        http = Net::HTTP.new(url.host, url.port)
        http.use_ssl = true
        http.verify_mode = OpenSSL::SSL::VERIFY_NONE

        request = Net::HTTP::Get.new(url)
        request["x-auth-token"] = "#{token}"
        request["cache-control"] = 'no-cache'

        response = http.request(request)
        json = JSON.parse(response.read_body)
        puts json["items"]
      end

      # Obtention de l'ID de la ligne avec le numéro de tel
      def self.get_line_id_from_number(number, token)
        line_id = 0
        url = URI("https://xivo.libriciel.fr:9486/1.1/lines")

        http = Net::HTTP.new(url.host, url.port)
        http.use_ssl = true
        http.verify_mode = OpenSSL::SSL::VERIFY_NONE

        request = Net::HTTP::Get.new(url)
        request["x-auth-token"] = "#{token}"
        request["cache-control"] = 'no-cache'

        response = http.request(request)
        json = JSON.parse(response.read_body)
        json2 = json["items"].to_a
        json2.each do |number_check|
          if number_check["caller_id_num"].to_i == number.to_i
            line_id = number_check["id"]
          else
          end

        end
        return line_id
      end

      # Obtention de l'ID du téléphone avec l'ID de la ligne
      def self.get_device_id_from_line(line_id, token)
        url = URI("https://xivo.libriciel.fr:9486/1.1/lines/#{line_id}/devices")

        http = Net::HTTP.new(url.host, url.port)
        http.use_ssl = true
        http.verify_mode = OpenSSL::SSL::VERIFY_NONE

        request = Net::HTTP::Get.new(url)
        request["x-auth-token"] = "#{token}"
        request["cache-control"] = 'no-cache'

        response = http.request(request)
        device_id = JSON.parse(response.read_body)

        return device_id["device_id"]
      end

      # Obtention de la mac du téléphone avec l'ID de ce dernier
      def self.get_device_mac_from_id(device_id, token)
        url = URI("https://xivo.libriciel.fr:9486/1.1/devices")

        http = Net::HTTP.new(url.host, url.port)
        http.use_ssl = true
        http.verify_mode = OpenSSL::SSL::VERIFY_NONE

        request = Net::HTTP::Get.new(url)
        request["x-auth-token"] = "#{token}"
        request["cache-control"] = 'no-cache'

        response = http.request(request)
        json = JSON.parse(response.read_body)

        json["items"].each do |devices|
          if devices["id"].to_s == device_id.to_s
            return devices["mac"]

          else
          end
        end

      end

      # Obtention de l'ID d'un téléphone avec sa mac
      def self.get_device_id_from_mac(mac, token)
        url = URI("https://xivo.libriciel.fr:9486/1.1/devices")

        http = Net::HTTP.new(url.host, url.port)
        http.use_ssl = true
        http.verify_mode = OpenSSL::SSL::VERIFY_NONE

        request = Net::HTTP::Get.new(url)
        request["x-auth-token"] = "#{token}"
        request["cache-control"] = 'no-cache'

        response = http.request(request)
        json = JSON.parse(response.read_body)

        json["items"].each do |devices|
          if devices["mac"].to_s == mac.to_s
            return devices["id"]

          else
          end
        end

      end

      # Suppression d'une associtaiton ligne / numéro
      # Attention ERROR 36 si pas associé à un device
      def self.del_association(line_id, device_id, token)
        url = URI("https://xivo.libriciel.fr:9486/1.1/lines/#{line_id}/devices/#{device_id}")

        http = Net::HTTP.new(url.host, url.port)
        http.use_ssl = true
        http.verify_mode = OpenSSL::SSL::VERIFY_NONE

        request = Net::HTTP::Delete.new(url)
        request["x-auth-token"] = "#{token}"
        request["cache-control"] = 'no-cache'


        response = http.request(request)

        unless response.read_body.to_s.strip.empty?
          STDERR.puts("Line is not associated with Device")
          exit(36)
        end
        sip_id_from_line = Libriciel::ApiXivo.get_sip_id_from_line(line_id, token)

        sip_add_options = Libriciel::ApiXivo.add_webrtc_of_sip(sip_id_from_line, token)

      end

      # Ajout d'une association entre un numéro et un téléphone
      # Attention ERROR 36 si deja associé à un device
      def self.add_association(line_id, device_id, token)
        url = URI("https://xivo.libriciel.fr:9486/1.1/lines/#{line_id}/devices/#{device_id}")

        http = Net::HTTP.new(url.host, url.port)
        http.use_ssl = true
        http.verify_mode = OpenSSL::SSL::VERIFY_NONE

        request = Net::HTTP::Put.new(url)
        request["x-auth-token"] = "#{token}"
        request["cache-control"] = 'no-cache'


        response = http.request(request)
        unless response.read_body.to_s.strip.empty?
          STDERR.puts("Line is already associated to a Device")
          exit(36)
        end
        sip_id_from_line = Libriciel::ApiXivo.get_sip_id_from_line(line_id, token)

        sip_del_options = Libriciel::ApiXivo.dell_webrtc_of_sip(sip_id_from_line, token)

      end

      # Synchronisation du device avec son ID
      def self.synchro_device_id(device_id, token)
        url = URI("https://xivo.libriciel.fr:9486/1.1/devices/#{device_id}/synchronize")

        http = Net::HTTP.new(url.host, url.port)
        http.use_ssl = true
        http.verify_mode = OpenSSL::SSL::VERIFY_NONE

        request = Net::HTTP::Get.new(url)
        request["x-auth-token"] = "#{token}"
        request["cache-control"] = 'no-cache'

        response = http.request(request)
        puts response.read_body

      end

      # Export en csv de tous les utilisateurs xivo
      def self.export_all_users_to_csv(xivo_csv_file, token)
        url = URI("https://xivo.libriciel.fr:9486/1.1/users/export")

        http = Net::HTTP.new(url.host, url.port)
        http.use_ssl = true
        http.verify_mode = OpenSSL::SSL::VERIFY_NONE

        request = Net::HTTP::Get.new(url)
        request["x-auth-token"] = "#{token}"
        request["cache-control"] = 'no-cache'


        response = http.request(request)

        File.open("#{xivo_csv_file}", "w") {|f| f.write(response.read_body)}
        return xivo_csv_file

      end

      # Ajotu d'un nouvel utilisateurs avec création de son numéro (get_free_sip)
      # et passage du password dans le csv_entry
      def self.add_new_user(csv_entry, token)
        url = URI("https://xivo.libriciel.fr:9486/1.1/users/import")

        http = Net::HTTP.new(url.host, url.port)
        http.use_ssl = true
        http.verify_mode = OpenSSL::SSL::VERIFY_NONE

        request = Net::HTTP::Post.new(url)
        request["x-auth-token"] = "#{token}"
        request["content-type"] = 'text/csv; charset=utf-8'
        request["cache-control"] = 'no-cache'
        request.body = csv_entry

        response = http.request(request)
      end


      ## Recherche du sip_id en fonction du numéro en entrée
      def self.get_sip_id_from_line(line_id, token)
        url = URI("https://xivo.libriciel.fr:9486/1.1/lines/#{line_id}/endpoints/sip")

        http = Net::HTTP.new(url.host, url.port)
        http.use_ssl = true
        http.verify_mode = OpenSSL::SSL::VERIFY_NONE

        request = Net::HTTP::Get.new(url)
        request["x-auth-token"] = "#{token}"
        request["cache-control"] = 'no-cache'

        response = http.request(request)
        json = JSON.parse(response.read_body)

        return json["endpoint_id"]
      end

      ## Recherche des options du numéro SIP (à faire : traitement pour ajout et enlevement webrtc)
      def self.get_sip_options(sip_id, token)
        options_line = "[\n        "
        url = URI("https://xivo.libriciel.fr:9486/1.1/endpoints/sip/#{sip_id}")

        http = Net::HTTP.new(url.host, url.port)
        http.use_ssl = true
        http.verify_mode = OpenSSL::SSL::VERIFY_NONE

        request = Net::HTTP::Get.new(url)
        request["x-auth-token"] = "#{token}"
        request["cache-control"] = 'no-cache'

        response = http.request(request)
        json = JSON.parse(response.read_body)
        json["options"].each do |options|
          if options[0] == "callerid"
            options[1] = options[1].gsub(/\"/, "\\\"")

            options_line << "[\n            \"#{options[0]}\",\n            \"#{options[1]}\"\n            ],\n            "
          else
            options_line << "[\n            \"#{options[0]}\",\n            \"#{options[1]}\"\n            ],\n            "
          end
        end

        return options_line.gsub(/,\n            $/, "\n]\n")
      end

      def self.dell_webrtc_of_sip(sip_id, token)
        options = Libriciel::ApiXivo.get_sip_options(sip_id, token)
        if options.include?("webrtc")
          options_less_webrtc = "{\n \"options\": #{options.gsub(/\,\n            \[\n            \"webrtc\"\,\n            \"yes\"\n            \]/, '')}}"

        else
        end

        url = URI("https://xivo.libriciel.fr:9486/1.1/endpoints/sip/#{sip_id}")

        http = Net::HTTP.new(url.host, url.port)
        http.use_ssl = true
        http.verify_mode = OpenSSL::SSL::VERIFY_NONE

        request = Net::HTTP::Put.new(url)
        request["x-auth-token"] = "#{token}"
        request["content-type"] = 'application/json'
        request["cache-control"] = 'no-cache'
        request.body = "#{options_less_webrtc}"

        response = http.request(request)

      end

      def self.add_webrtc_of_sip(sip_id, token)
        options = Libriciel::ApiXivo.get_sip_options(sip_id, token)
        if !options.include?("webrtc")
          options_plus_webrtc = "{\n \"options\": #{options.gsub(/\]\n\]$/, "],\n            \[\n            \"webrtc\",\n            \"yes\"\n            ]\n]")}}"

        else
          STDERR.puts("webrtc already configured")
          exit 1
        end

        url = URI("https://xivo.libriciel.fr:9486/1.1/endpoints/sip/#{sip_id}")

        http = Net::HTTP.new(url.host, url.port)
        http.use_ssl = true
        http.verify_mode = OpenSSL::SSL::VERIFY_NONE

        request = Net::HTTP::Put.new(url)
        request["x-auth-token"] = "#{token}"
        request["content-type"] = 'application/json'
        request["cache-control"] = 'no-cache'
        request.body = "#{options_plus_webrtc}"

        response = http.request(request)

      end

    end

    # Class GetConfig for chef deploy
    class GetConfig
      require 'fileutils'

      ## Partie pour Pastell à contnuer
      def self.compare_files_pastell(default_config_file_parse, conf_file_open, conf_file, libriciel, caracs_to_extract_from, default_config_file)
        if !default_config_file_parse[libriciel]
          default_config_file_parse[libriciel] = {}

        end

        if File.readlines(conf_file).grep(/BD_/).size > 0
          conf_file_parse = JSON.parse(File.read(conf_file))
          if !default_config_file_parse[libriciel]["database"]
            default_config_file_parse[libriciel]["database"] = {}

          end

          conf_file_parse.keys.each do |valeur_tableau_configuration|

            if valeur_tableau_configuration.include? "BD_"
              case valeur_tableau_configuration
              when "BD_USER"
                default_config_file_parse[libriciel]["database"]["user"] = conf_file_parse[valeur_tableau_configuration]

              when "BD_PASS"
                default_config_file_parse[libriciel]["database"]["password"] = conf_file_parse[valeur_tableau_configuration]

              when "BD_DSN"

                default_config_file_parse[libriciel]["database"]["host_conf"] = conf_file_parse[valeur_tableau_configuration]

              end
            elsif valeur_tableau_configuration == "hostname"
              default_config_file_parse[libriciel]["fullname"] = conf_file_parse[valeur_tableau_configuration]

            elsif valeur_tableau_configuration == "mail.from"
              default_config_file_parse[libriciel]["domain"] = conf_file_parse[valeur_tableau_configuration].gsub(/\S*@/, "")

            end
          end
        end
      end

      # Partie pour Webdelib à continuer
      def self.compare_files_webdelib(default_config_file_parse, conf_file_open, conf_file, libriciel, caracs_to_extract_from, default_config_file)

      end

      def self.compare_files_iparapheur(default_config_file_parse, conf_file_open, conf_file, libriciel, caracs_to_extract_from, default_config_file)
        ## Schema pour le Xmx
        ## default['iparapheur']['ctl']['xms'] pour le iParapheur
        ## ["-Xmx": "xxxxm", "-Xms": "xxxxm"] pour le parse_spec_conf
        if !default_config_file_parse[libriciel]
          default_config_file_parse[libriciel] = {}

        end

        case

        ## Xmx et Xms
        ## Lancement du parse pour voir les bonnes valeurs des Xmx et xms
        ## Puis mise en place dans le config.json au cas ou pas existant
        when File.readlines(conf_file).grep(/Xms|Xmx/).size > 0
          tableau = {}
          tabs = parse_spec_conf(conf_file, caracs_to_extract_from, tableau, nil)

          if !default_config_file_parse[libriciel]["ctl"]
            default_config_file_parse[libriciel]["ctl"] = {}

          end

          if default_config_file_parse[libriciel]["ctl"].empty?
           default_config_file_parse[libriciel]["ctl"] = default_config_file_parse[libriciel]["ctl"].merge(tabs)

          else
           default_config_file_parse[libriciel]["ctl"] = tabs



          end

        ## database vérification et surcharge des
        ## entrée dans le config.json pour régénération
        when File.readlines(conf_file).grep(/db./).size > 0
          conf_file_parse = JSON.parse(File.read(conf_file))
          if !default_config_file_parse[libriciel]["database"]
            default_config_file_parse[libriciel]["database"] = {}

          end

          conf_file_parse.keys.each do |valeur_tableau_configuration|

            if valeur_tableau_configuration.include? "db."
              case valeur_tableau_configuration
              when "db.username"
                default_config_file_parse[libriciel]["database"]["user"] = conf_file_parse[valeur_tableau_configuration]

              when "db.password"
                default_config_file_parse[libriciel]["database"]["password"] = conf_file_parse[valeur_tableau_configuration]

              when "db.name"
                default_config_file_parse[libriciel]["database"]["name"] = conf_file_parse[valeur_tableau_configuration]

              when "db.url"
                default_config_file_parse[libriciel]["database"]["host_conf"] = conf_file_parse[valeur_tableau_configuration].gsub("jdbc:mysql://", "").gsub(/\/#{conf_file_parse["db.name"]}\z/, "")

              end
            elsif valeur_tableau_configuration == "hostname"
              default_config_file_parse[libriciel]["fullname"] = conf_file_parse[valeur_tableau_configuration]

            elsif valeur_tableau_configuration == "mail.from"
              default_config_file_parse[libriciel]["domain"] = conf_file_parse[valeur_tableau_configuration].gsub(/\S*@/, "")

            end
          end
        else
          puts "autres parametres"
        end

        ## Ici pour surcharge de mes valeurs par défaut du config .JSON
        ## Qui est généré par défaut
        File.open("#{default_config_file}", "w") {|f| f.write(JSON.pretty_generate(default_config_file_parse))}
      end

      ## Fonction pour la table de correspondance qui va permettre
      ## D'ajouter au config.json existant les bonnes valeurs
      ## Par exemple le db.host avec le "database" : "hostname" = "" pour
      def self.table_comparaison(all_conf_files, caracs_to_extract_from, libriciel, default_config_file)
        default_config_file_parse = JSON.parse(File.read(default_config_file))
        all_conf_files.each do |conf_file|
          conf_file_open = File.open(conf_file)

          case libriciel
          when "iparapheur"
            compare_files_iparapheur(default_config_file_parse, conf_file_open, conf_file, libriciel, caracs_to_extract_from, default_config_file)

          when "webdelib"
            compare_files_webdelib(default_config_file_parse, conf_file_open,conf_file, libriciel, caracs_to_extract_from, default_config_file)

          when "pastell"
            compare_files_pastell(default_config_file_parse, conf_file_open, conf_file, libriciel, caracs_to_extract_from, default_config_file)

          else
            puts "Outils pas dans la liste"
          end
        end
      end


      ## Fonction pour l'extraction d'une chaine de caractère
      ## (par exemple le xmx et le xms dans le ctl.sh)
      ## Fichier en entrée, la ou les chaines de caractères à parser
      ## Petit tableau en retours pour pouvoir le faire corrspondre au tableau
      def self.parse_spec_conf(conf_file, caracs_to_extract_from, carac_tableau, separateur)
        conf_file_open = File.open(conf_file)

        conf_file_open.each_line do |line|
          line_split = line.split

          caracs_to_extract_from.each do |carac_to_split|
            if line.include? carac_to_split
              line_grep = line_split.grep(/#{carac_to_split}/)
              carac_mis_en_forme = carac_to_split.gsub(/[^0-9A-Za-z]/, '').to_s.downcase

              line_grep.each do |line_to_gsub|
                if !carac_mis_en_forme.empty?
                  carac_tableau[carac_mis_en_forme] = line_to_gsub.gsub("#{carac_to_split}", '').gsub(/[^0-9A-Za-z]/, '')

                else
                  # puts "entrée vide"
                end

              end
            end
          end
        end
        return carac_tableau

      end

      # Fonction qui va prendre le tableau généré par celle ci pour le lire et inscrire dans
      #le conf.json parsé au bon endroit "iparpaheur": {} par exemple les valeurs pour etre ready pour la mise à jour
      def self.concat_config_json(config_json_file, tableau, libriciel)
        config_json_file_parse = JSON.parse(File.read(config_json_file))
        config_json_file_parse[libriciel] = config_json_file_parse[libriciel].merge(tableau)

        ## Ici pour surcharge de mes valeurs par défaut du config .JSON
        ## Qui est généré par défaut
        File.open("#{config_json_file}", "w") {|f| f.write(JSON.pretty_generate(config_json_file_parse))}

      end

      #faire une seconde fonction qui va prendre le tableau généré par celle ci pour le lire et inscrire dans
      #le conf.json parsé au bon endroit "iparapheur": {} par exemple les valeurs pour etre ready pour la mise à jour
      def self.compare_json(template_json, conf_json, table_valeur_diff)
        if !FileUtils.compare_file(template_json, conf_json)

          template_file_json = JSON.parse(File.read(template_json))
          conf_file_json = JSON.parse(File.read(conf_json))

          template_file_json.keys.each do |keys_template_file_lvl_1|

            if !conf_file_json.keys.include? keys_template_file_lvl_1
              puts "#{keys_template_file_lvl_1}"
              puts "Attention pas bonne syntaxe de la configuration"
              exit 222
            else
              if conf_file_json[keys_template_file_lvl_1] == template_file_json[keys_template_file_lvl_1]

              else

                ## Les if suivants sur le conf_json sont exclusif pour le iParapheur et
                ## la mise en place de l'aborescence du config.json
                if File.basename(conf_json) == "iparapheur-global.properties.json"
                  keys_template_file_ip = "ihm"

                  if !table_valeur_diff[keys_template_file_ip]
                    table_valeur_diff[keys_template_file_ip] = {}

                  end
                  table_valeur_diff["ihm"][keys_template_file_lvl_1] = conf_file_json[keys_template_file_lvl_1]

                elsif File.basename(conf_json) == "alfresco-global.properties.json"
                  keys_template_file_ip = "alf"

                  if !table_valeur_diff[keys_template_file_ip]
                    table_valeur_diff[keys_template_file_ip] = {}

                  end
                  table_valeur_diff["alf"][keys_template_file_lvl_1] = conf_file_json[keys_template_file_lvl_1]

                else
                  table_valeur_diff[keys_template_file_lvl_1] = conf_file_json[keys_template_file_lvl_1]

                end
              end
            end
          end

        else
          # Mettre en place gestion des erreurs et raises
        end

        # Return du tableau avec les infos à ajouter au tableau config.json parsé
        return table_valeur_diff
      end

      # Générateur du config.json avec les infos modifiées du fichier de configuration
      # par rapport au template
      def self.config_json_generator(template_json_file, config_json_file, libriciel, default_config_json)
        tableau = {}
        template_json_file.each do |each_template|
          config_json_file.each do |each_conf_files|
            if File.basename(each_template) == File.basename(each_conf_files)
              compare_json(each_template, each_conf_files, tableau)
              concat_config_json(default_config_json, tableau, libriciel)
            #else
              # Le test donne deux fichier différents qui n'ont pas à etre comparés
            end
          end
        end
      end

      ## Fonction permettant de parser les fichiers de properties iParapheur en JSON
      def self.ip_conf_to_json(line, tableau)
        array_properties_value = line.split(/[=\n]+/)
        array_properties_dot_split = array_properties_value[0].split(/[\.\n]+/)

        if array_properties_dot_split[0].include? "parapheur"
           array_properties_parapheur_split = array_properties_value[0].split(/parapheur\./)
           tableau[array_properties_parapheur_split[1]] = array_properties_value[1]

        elsif array_properties_value[0].include? "authentication.chain" or array_properties_value[0].include? "alfresco.authentication.allowGuestLogin" or array_properties_value[0].include? "synchronization.autoCreatePeopleOnLogin"
            if array_properties_value[0].include? "#"
              array_properties_value[0] = array_properties_value[0].gsub("#", "")
              tableau[array_properties_value[0]] = array_properties_value[1]
            else
              tableau[array_properties_value[0]] = array_properties_value[1]
            end
        else
            tableau[array_properties_value[0]] = array_properties_value[1]

        end
        return tableau
      end

      ## Fonction permettant de parser les fichiers de conf pastell en json
      def self.pa_conf_to_json(line, tableau)
        tmp_clean = line.gsub(/define\(/, "").gsub(/\);/, "")
        array_properties_value = tmp_clean.split(/[, \n]+/)

        tableau[array_properties_value[0]] = array_properties_value[1].gsub(/\\;/, "")

        return tableau
      end

      ## Fonction permettant de parser les fichiers de conf webdelib en json
      def self.wd_conf_to_json(line, tableau)
        tmp_clean = line.gsub(/Configure::write\(/, "").gsub(/\);/, "")
        array_properties_value = tmp_clean.split(/[, \n]+/)

        tableau[array_properties_value[0]] = array_properties_value[1]

        return tableau
      end

      # Fonction qui fait le parsing des fichiers en confs en data_bag
      def self.parsing_conf(files, directory_json)
        Array(files).each do |file|

          # Récupération des nom de fichier dans la chemin absolu
          array_absolute_path_to_file = file.split('/')
          config_file_to_write = "/tmp/#{array_absolute_path_to_file.last}.json"

          config_files = File.open(file).read

          # Si existant on surcharge
          File.open("#{config_file_to_write}", "w") {|f| f.write("") }

          tableau = {}
          ## Passage de chaque ligne en json pour le fichier de conf en cours
          config_files.each_line do |line|
            if line.include? "define("
              pa_conf_to_json(line, tableau)

            elsif line.include? "Configure::write("
              wd_conf_to_json(line, tableau)

            elsif line.include? "="
              if !line[0,1].include? "#" or line.include? "ldap"
                ip_conf_to_json(line, tableau)
              end

            end
          end

          ## Ecriture du parsing en json du tableau généré par les fonctions dans le fichier json
          File.open("#{config_file_to_write}", "a") {|f| f.write(JSON.pretty_generate(tableau)) }

          ## Copie des fichiers dans le répertoire commun
          mv_json("#{config_file_to_write}", directory_json.to_s)
        end
      end



        def self.mv_json(files, directory)
            FileUtils.mv(files, directory)
        end

        def self.cp_json(files, directory)
            FileUtils.cp(files, directory)
        end
    end
end
